==> haskell-hookup-0.8-115.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hookup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hookup
version:              0.8
visibility:           public
id:                   hookup-0.8-FTrv33CvjoB3JzbnIPJ26F
key:                  hookup-0.8-FTrv33CvjoB3JzbnIPJ26F
license:              ISC
copyright:            2016-2020 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:
    Abstraction over creating network connections with SOCKS5 and TLS

description:
    This package provides an abstraction for communicating with line-oriented
    network services while abstracting over the use of SOCKS5 and TLS (via OpenSSL)

category:             Network
abi:                  458de81810454ce930580e23aa3a5f0e
exposed:              True
exposed-modules:      Hookup Hookup.OpenSSL
hidden-modules:       Hookup.Socks5 Hookup.Concurrent
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hookup-0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hookup-0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hookup-0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hookup
hs-libraries:         HShookup-0.8-FTrv33CvjoB3JzbnIPJ26F
depends:
    HsOpenSSL-0.11.7.9-96EVs0QSsusKamWieCsd7F
    HsOpenSSL-x509-system-0.1.0.4-HwaN78mhRl44e2zD0493V8
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    bytestring-0.11.5.3 network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    stm-2.5.1.0

haddock-interfaces:   /usr/share/doc/haskell-hookup/html/hookup.haddock
haddock-html:         /usr/share/doc/haskell-hookup/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hookup-0.8-116-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hookup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hookup
version:              0.8
visibility:           public
id:                   hookup-0.8-DivyDGc8pMD8pl6OOxNSe3
key:                  hookup-0.8-DivyDGc8pMD8pl6OOxNSe3
license:              ISC
copyright:            2016-2020 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:
    Abstraction over creating network connections with SOCKS5 and TLS

description:
    This package provides an abstraction for communicating with line-oriented
    network services while abstracting over the use of SOCKS5 and TLS (via OpenSSL)

category:             Network
abi:                  fd267d4aab6725469e746a3d528e78e0
exposed:              True
exposed-modules:      Hookup Hookup.OpenSSL
hidden-modules:       Hookup.Socks5 Hookup.Concurrent
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hookup-0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hookup-0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hookup-0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hookup
hs-libraries:         HShookup-0.8-DivyDGc8pMD8pl6OOxNSe3
depends:
    HsOpenSSL-0.11.7.9-7b2YaIo8nxa5WFX252B8AR
    HsOpenSSL-x509-system-0.1.0.4-2nSveR9cYmDIPT2fjI97vW
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    bytestring-0.11.5.3 network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    stm-2.5.1.0

haddock-interfaces:   /usr/share/doc/haskell-hookup/html/hookup.haddock
haddock-html:         /usr/share/doc/haskell-hookup/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
